@@ -26,7 +26,7 @@ from IPython.core.magic import (
 )
 from IPython.core.magic_arguments import magic_arguments, argument, parse_argstring
 import sparkmagic.utils.configuration as conf
-from ..utils.resource_check import check_host_and_port
+from ..utils.resource_check import check_host_and_port, is_ssl_enabled
 
 # The class MUST call this class decorator at creation time
 # https://ipython.readthedocs.io/en/stable/config/custommagics.html
@@ -50,6 +50,7 @@ AUTH_TYPE_SET = {"Kerberos", "None", "Basic_Access"}
 KRB_FILE_DIR = "/etc"
 KRB_FILE_PATH = os.path.join(KRB_FILE_DIR, "krb5.conf")
 SPARK_SESSION_NAME_PREFIX = "sagemaker_studio_analytics_spark_session"
+INSTANCE_COLLECTION_TYPE_GROUP = "INSTANCE_GROUP"
 
 # Livy default port
 # https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-web-interfaces.html
@@ -59,6 +60,7 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 logger.addHandler(logging.StreamHandler(sys.stdout))
 
+
 def _magic_kernel_connect_to_emr(
     emr_client, args, emr_cluster, username, password, kernel_name
 ):
@@ -105,11 +107,7 @@ def _get_endpoint_magic_line(
         args=args, emr_client=emr_client, emr_cluster=emr_cluster
     )
 
-    # fast fail by check livy port availability. If fail, do not proceed to compose the endpoint.
-    if not check_host_and_port(livy_host, int(livy_port)):
-        raise RuntimeError(f"Cannot connect to livy service: {livy_host}:{livy_port}")
-
-    livy_endpoint = "http://{0}:{1}".format(livy_host, livy_port)
+    livy_endpoint = _prepare_livy_endpoint(livy_host, int(livy_port))
     if kernel_name in MAGIC_KERNELS:
         return _get_magic_kernel_endpoint_magic_line(
             args=args,
@@ -126,6 +124,20 @@ def _get_endpoint_magic_line(
     )
 
 
+def _prepare_livy_endpoint(livy_host, livy_port):
+    # fast fail by check livy port availability. If fail, do not proceed to compose the endpoint.
+    if not check_host_and_port(livy_host, livy_port):
+        raise RuntimeError(f"Cannot connect to livy service: {livy_host}:{livy_port}")
+
+    protocol = "http"
+    if is_ssl_enabled(livy_host, livy_port):
+        protocol = "https"
+        _enable_ignore_ssl_errors()
+
+    livy_endpoint = "{0}://{1}:{2}".format(protocol, livy_host, livy_port)
+    return livy_endpoint
+
+
 def _get_livy_port(args, emr_client, emr_cluster):
     livy_port = LIVY_DEFAULT_PORT
 
@@ -134,7 +146,13 @@ def _get_livy_port(args, emr_client, emr_cluster):
     )
     if livy_port_from_cluster_configuration:
         livy_port = livy_port_from_cluster_configuration
-    else:
+    # Given the logic cannot support EMR with INSTANCE_FLEET enabled. To avoid unexpected failure, check
+    # InstanceCollectionType before calling logic to get livy port from instance group. This help unblock customer who
+    # is using INSTANCE_FLEET but has no requirement to have custom livy port configured on instance fleet level.
+    # Next step, we will add full support for livy port configured on instance fleet level.
+    elif (
+        _get_emr_instance_collection_type(emr_cluster) == INSTANCE_COLLECTION_TYPE_GROUP
+    ):
         livy_port_from_instance_group = _get_livy_port_from_instance_group(
             emr_client=emr_client,
             args=args,
@@ -144,6 +162,18 @@ def _get_livy_port(args, emr_client, emr_cluster):
     return livy_port
 
 
+def _get_emr_instance_collection_type(emr_cluster):
+    """
+    Get EMR instance collection type.
+    The instance fleet configuration is available only in Amazon EMR versions 4.8.0 and later, excluding 5.0.x versions.
+    The EMR version 5.9.0 starts to support livy which is a pre-condition to work with Studio. So we can safely assume
+    the InstanceCollectionType is available.
+    :param emr_cluster: EMR cluster
+    :return: InstanceCollectionType with valid Values: INSTANCE_FLEET | INSTANCE_GROUP
+    """
+    return emr_cluster.__dict__.get("_cluster").get("InstanceCollectionType")
+
+
 def _run_preset_cell_magics(ipy):
     # To allow retry on user errors without kernel restart
     allow_retry_fatal = ipy.find_cell_magic("_do_not_call_allow_retry_fatal")
@@ -176,16 +206,23 @@ def _get_lock():
             lock.release(force=True)
     return lock
 
+
 class IpythonWidgetBasedAuthProvider:
     """
     Class responsible for retrieving credentials needed to connect to EMR cluster.
     """
-    def get_credentials_and_connect_to_cluster(self, emr_client, args, emr_cluster, kernel_name):
+
+    def get_credentials_and_connect_to_cluster(
+        self, emr_client, args, emr_cluster, kernel_name
+    ):
         username = widgets.Text(
             value="", placeholder="", description="Username:", disabled=False
         )
         password = widgets.Password(
-            value="", placeholder="Enter password", description="Password:", disabled=False
+            value="",
+            placeholder="Enter password",
+            description="Password:",
+            disabled=False,
         )
         display(username, password)
         button = widgets.Button(
@@ -207,11 +244,12 @@ class IpythonWidgetBasedAuthProvider:
                     emr_cluster=emr_cluster,
                     kernel_name=kernel_name,
                     username=username.value,
-                    password=password.value
+                    password=password.value,
                 )
 
         button.on_click(_on_button_clicked)
 
+
 def _connect_to_cluster(emr_client, args, emr_cluster, kernel_name, username, password):
     if args.auth_type == "Basic_Access":
         _initiate_connect_based_on_kernel(
@@ -226,8 +264,8 @@ def _connect_to_cluster(emr_client, args, emr_cluster, kernel_name, username, pa
         # At this point lock should be available to acquire if another process has not already taken it
         # Go ahead and try to use the "with" context directly
         with _get_lock().acquire(
-                # Try for 15 seconds to acquire the lock, otherwise fail with lock acquire failure
-                timeout=15
+            # Try for 15 seconds to acquire the lock, otherwise fail with lock acquire failure
+            timeout=15
         ):
             completed_process = _generate_kerberos_token(
                 emr_cluster=emr_cluster, username=username, password=password
@@ -246,6 +284,7 @@ def _connect_to_cluster(emr_client, args, emr_cluster, kernel_name, username, pa
                     args=args, completed_process=completed_process
                 )
 
+
 def _generate_kerberos_token(emr_cluster, username, password):
     # noinspection PyTypeChecker
     write_krb_conf(emr_cluster, KRB_FILE_PATH)
@@ -397,6 +436,13 @@ def _handle_kerberos_endpoint_override(emr_cluster):
         )
 
 
+def _enable_ignore_ssl_errors():
+    """
+    Set ignore_ssl_errors as true so the self-signed certificate can be accepted.
+    """
+    conf.override(conf.ignore_ssl_errors.__name__, True)
+
+
 def _get_livy_port_from_cluster_configuration(emr_cluster):
     emr_configuration_list = emr_cluster.__dict__.get("_cluster").get("Configurations")
     # For cluster configuration
